<?php
/**
 * Theme Customizer.
 *
 * @package WEN_Associate
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_associate_customize_register( $wp_customize ) {

	// Modify background color field message.
	$wp_customize->get_control( 'background_color' )->description = __( 'Note: Background Color is applicable only if Boxed Layout used and no image is set as Background Image.', 'wen-associate' );

	// Color - Main Background Section.
	$wp_customize->add_section( 'section_color_main_background',
		array(
			'title'       => esc_html__( 'Main Background', 'wen-associate' ),
			'priority'    => 1,
			'capability'  => 'edit_theme_options',
			'panel'       => 'color_settings_panel',
		)
	);
	$wp_customize->get_control( 'background_color' )->section = 'section_color_main_background';

}

add_action( 'customize_register', 'wen_associate_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since 2.0.0
 *
 * @return void
 */
function wen_associate_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since 2.0.0
 *
 * @return void
 */
function wen_associate_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Customizer partials.
 *
 * @since 2.0.0
 */
function wen_associate_customizer_partials( WP_Customize_Manager $wp_customize ) {

    // Abort if selective refresh is not available.
    if ( ! isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->get_setting( 'blogname' )->transport        = 'refresh';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'refresh';
        return;
    }

	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

    // Partial blogname.
    $wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector'            => '.site-title a',
		'container_inclusive' => false,
		'render_callback'     => 'wen_associate_customize_partial_blogname',
    ) );

    // Partial blogdescription.
    $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector'            => '.site-description',
		'container_inclusive' => false,
		'render_callback'     => 'wen_associate_customize_partial_blogdescription',
    ) );
}

add_action( 'customize_register', 'wen_associate_customizer_partials', 99 );
