<?php
/**
 * Helper functions.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_get_featured_slider_transition_effects' ) ) :

	/**
	 * Returns the featured slider transition effects.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_featured_slider_transition_effects() {

		$choices = array(
			'fade'       => _x( 'fade', 'Transition Effect', 'wen-associate' ),
			'fadeout'    => _x( 'fadeout', 'Transition Effect', 'wen-associate' ),
			'none'       => _x( 'none', 'Transition Effect', 'wen-associate' ),
			'scrollHorz' => _x( 'scrollHorz', 'Transition Effect', 'wen-associate' ),
			'tileSlide'  => _x( 'tileSlide', 'Transition Effect', 'wen-associate' ),
			'tileBlind'  => _x( 'tileBlind', 'Transition Effect', 'wen-associate' ),
			'flipHorz'   => _x( 'flipHorz', 'Transition Effect', 'wen-associate' ),
			'flipVert'   => _x( 'flipVert', 'Transition Effect', 'wen-associate' ),
			'shuffle'    => _x( 'shuffle', 'Transition Effect', 'wen-associate' ),
		);
		$output = apply_filters( 'wen_associate_filter_featured_slider_transition_effects', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_get_featured_slider_content_options' ) ) :

	/**
	 * Returns the featured slider content options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_featured_slider_content_options() {

		$choices = array(
			'home-page-only' => __( 'Home Page Only', 'wen-associate' ),
			'home-blog-page' => __( 'Home Page + Blog Page', 'wen-associate' ),
			'entire-site'    => __( 'Entire Site', 'wen-associate' ),
			'disabled'       => __( 'Disabled', 'wen-associate' ),
			);
		$output = apply_filters( 'wen_associate_filter_featured_slider_content_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_get_featured_slider_type' ) ) :

	/**
	 * Returns the featured slider type.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_featured_slider_type() {

		$choices = array(
			'featured-category' => __( 'Featured Category', 'wen-associate' ),
			'featured-page'     => __( 'Featured Pages', 'wen-associate' ),
			'featured-post'     => __( 'Featured Posts', 'wen-associate' ),
			'featured-image'    => __( 'Featured Images', 'wen-associate' ),
			'featured-tag'      => __( 'Featured Tag', 'wen-associate' ),
			);

		$output = apply_filters( 'wen_associate_filter_featured_slider_type', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_associate_get_featured_slider_design_options' ) ) :

	/**
	 * Returns the featured slider design options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_featured_slider_design_options() {

		$choices = array(
			'circle'    => __( 'Circle', 'wen-associate' ),
			'rectangle' => __( 'Rectangle', 'wen-associate' ),
			);

		$output = apply_filters( 'wen_associate_filter_featured_slider_design_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_associate_get_menu_alignment_options' ) ) :

	/**
	 * Returns menu options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_menu_alignment_options() {

		$choices = array(
			'left'   => __( 'Left', 'wen-associate' ),
			'center' => __( 'Center', 'wen-associate' ),
			'right'  => __( 'Right', 'wen-associate' ),
			);
		return $choices;

	}

endif;

if ( ! function_exists( 'wen_associate_get_meta_footer_layout_options' ) ) :

	/**
	 * Returns meta footer layout options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_meta_footer_layout_options() {

		$choices = array(
			'default' => __( 'Default', 'wen-associate' ),
			'compact' => __( 'Compact', 'wen-associate' ),
			);
		$output = apply_filters( 'wen_associate_filter_meta_footer_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_global_layout_options() {

		$choices = array(
			'left-sidebar'            => __( 'Primary Sidebar - Content', 'wen-associate' ),
			'right-sidebar'           => __( 'Content - Primary Sidebar', 'wen-associate' ),
			'three-columns'           => __( 'Three Columns ( Secondary - Content - Primary )', 'wen-associate' ),
			'three-columns-pcs'       => __( 'Three Columns ( Primary - Content - Secondary )', 'wen-associate' ),
			'three-columns-cps'       => __( 'Three Columns ( Content - Primary - Secondary )', 'wen-associate' ),
			'three-columns-psc'       => __( 'Three Columns ( Primary - Secondary - Content )', 'wen-associate' ),
			'three-columns-pcs-equal' => __( 'Three Columns ( Equal Primary - Content - Secondary )', 'wen-associate' ),
			'three-columns-scp-equal' => __( 'Three Columns ( Equal Secondary - Content - Primary )', 'wen-associate' ),
			'no-sidebar'              => __( 'No Sidebar ( Full Width )', 'wen-associate' ),
			'no-sidebar-centered'     => __( 'No Sidebar ( Centered Content )', 'wen-associate' ),
			);

		$output = apply_filters( 'wen_associate_filter_layout_options', $choices );
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_get_site_layout_options' ) ) :

	/**
	 * Returns site options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_site_layout_options() {

		$choices = array(
			'fluid' => __( 'Fluid', 'wen-associate' ),
			'boxed' => __( 'Boxed', 'wen-associate' ),
			);
		$output = apply_filters( 'wen_associate_filter_site_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_archive_layout_options() {

		$choices = array(
			'full'    => __( 'Full Post', 'wen-associate' ),
			'excerpt' => __( 'Post Excerpt', 'wen-associate' ),
			);
		$output = apply_filters( 'wen_associate_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_associate_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable True for adding No Image option.
	 * @param array $allowed Allowed image size options.
	 * @param bool  $show_dimension True for displaying dimension.
	 * @return array Image size options.
	 */
	function wen_associate_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;
		$get_intermediate_image_sizes = get_intermediate_image_sizes();
		$choices = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'wen-associate' );
		}
		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'wen-associate' );
		$choices['medium']    = esc_html__( 'Medium', 'wen-associate' );
		$choices['large']     = esc_html__( 'Large', 'wen-associate' );
		$choices['full']      = esc_html__( 'Full (original)', 'wen-associate' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ) {
					$choices[ $key ] .= ' ('. $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;

	}

endif;



if ( ! function_exists( 'wen_associate_get_image_alignment_options' ) ) :

	/**
	 * Returns single image alignment options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_image_alignment_options() {

		$choices = array(
			'none'   => _x( 'None', 'Alignment', 'wen-associate' ),
			'left'   => _x( 'Left', 'Alignment', 'wen-associate' ),
			'center' => _x( 'Center', 'Alignment', 'wen-associate' ),
			'right'  => _x( 'Right', 'Alignment', 'wen-associate' ),
			);
		return $choices;

	}

endif;


if ( ! function_exists( 'wen_associate_get_pagination_type_options' ) ) :

	/**
	 * Returns pagination type options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_pagination_type_options() {

		$choices = array(
			'default'               => __( 'Default (Older / Newer Post)', 'wen-associate' ),
			'numeric'               => __( 'Numeric', 'wen-associate' ),
			'infinite-scroll'       => __( 'Infinite Scroll - Scroll', 'wen-associate' ),
			'infinite-scroll-click' => __( 'Infinite Scroll - Click', 'wen-associate' ),
			);
		return $choices;

	}

endif;


if ( ! function_exists( 'wen_associate_get_breadcrumb_type_options' ) ) :

	/**
	 * Returns breadcrumb type options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_breadcrumb_type_options() {

		$choices = array(
			'disabled' => __( 'Disabled', 'wen-associate' ),
			'simple'   => __( 'Simple', 'wen-associate' ),
			'advanced' => __( 'Advanced', 'wen-associate' ),
			);
		return $choices;

	}

endif;

if ( ! function_exists( 'wen_associate_get_header_layout_options' ) ) :

	/**
	 * Returns header layout options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_header_layout_options() {

		$choices = array(
			'layout-1' => get_template_directory_uri() . '/images/header-layout-1.png',
			'layout-2' => get_template_directory_uri() . '/images/header-layout-2.png',
			);
		return $choices;

	}

endif;


if ( ! function_exists( 'wen_associate_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_font_family_theme_settings_options() {

		$choices = array(
			'font_site_title' => array(
				'label'   => __( 'Site Title', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_site_tagline' => array(
				'label'   => __( 'Site Tagline', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_site_default' => array(
				'label'   => __( 'Default', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_content_title' => array(
				'label'   => __( 'Content Title', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_content_body' => array(
				'label'   => __( 'Content Body', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_heading_tags' => array(
				'label'   => __( 'Heading Tags', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_navigation' => array(
				'label'   => __( 'Navigation', 'wen-associate' ),
				'default' => 'lato',
				),
			'font_widget_title' => array(
				'label'   => __( 'Widget Title', 'wen-associate' ),
				'default' => 'oswald',
				),
			);
		return $choices;

	}

endif;


if ( ! function_exists( 'wen_associate_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_web_fonts() {

		$choices = array(
			'open-sans' => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
				),
			'roboto' => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
				),
			'raleway' => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
				),
			'droid-sans' => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
				),
			'lato' => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
				),
			'dosis' => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
				),
			'slabo-27px' => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
				),
			'oswald' => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
				),
			'pt-sans-narrow' => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
				),
			'josefin-slab' => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
				),
			'alegreya' => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
				),
			'exo' => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
				),
			'signika' => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
				),
			'lobster' => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', sans-serif",
				),
			);
		$choices = apply_filters( 'wen_associate_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if ( ! function_exists( 'wen_associate_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_os_fonts() {

		$choices = array(
			'arial' => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
				),
			'georgia' => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
				),
			'cambria' => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
				),
			'tahoma' => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
				),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
				),
			'verdana' => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
				),
			);
		$choices = apply_filters( 'wen_associate_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if ( ! function_exists( 'wen_associate_get_customizer_font_options' ) ) :

	/**
	 * Returns customizer font options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_customizer_font_options() {

		$web_fonts = wen_associate_get_web_fonts();
		$os_fonts  = wen_associate_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[ $k ] = esc_html( $v['label'] );
			}
		}
		return $choices;

	}

endif;


if ( ! function_exists( 'wen_associate_get_default_colors' ) ) :

	/**
	 * Returns default colors.
	 *
	 * @since 1.0.0
	 *
	 * @param string $scheme Scheme.
	 * @return array Color array according to scheme.
	 */
	function wen_associate_get_default_colors( $scheme = 'default' ) {

		$output = array();

		switch ( $scheme ) {

			case 'default':
			default:
				$output = array(

				// Basic.
				'color_basic_background'              => '#f9f9f9',
				'color_basic_text'                    => '#6e6e6e',
				'color_basic_link'                    => '#ff794c',
				'color_basic_link_hover'              => '#ff794c',
				'color_basic_heading'                 => '#545454',
				'color_basic_button_background'       => '#ff794c',
				'color_basic_button_text'             => '#ffffff',
				'color_basic_button_background_hover' => '#ff794c',
				'color_basic_button_text_hover'       => '#ffffff',

				// Header.
				'color_header_background'  => '#f9f9f9',
				'color_header_title'       => '#ff794c',
				'color_header_title_hover' => '#ff794c',
				'color_header_tagline'     => '#666666',

				// Header Top.
				'color_header_top_background'                  => '#858585',
				'color_header_top_contact_icon'                => '#ff794c',
				'color_header_top_contact_link'                => '#ffffff',
				'color_header_top_contact_link_hover'          => '#ff794c',
				'color_header_top_contact_separator'              => '#ffffff',
				'color_header_top_quick_link'                  => '#ffffff',
				'color_header_top_quick_link_hover'            => '#ffffff',
				'color_header_top_quick_link_hover_background' => '#ff794c',
				'color_header_top_quick_link_separator'        => '#ffffff',

				// Content.
				'color_content_background'      => '#f9f9f9',
				'color_content_title'           => '#464637',
				'color_content_text'            => '#8c8b8b',
				'color_content_link'            => '#ff794c',
				'color_content_link_hover'      => '#ff794c',
				'color_content_meta_text'       => '#a7a9ac',
				'color_content_meta_link'       => '#ff794c',
				'color_content_meta_link_hover' => '#ff794c',
				'color_content_meta_icon'       => '#ff794c',

				// Sidebar.
				'color_sidebar_widget_background'   => '#fcfcfc',
				'color_sidebar_widget_title'        => '#464637',
				'color_sidebar_widget_title_border' => '#e6e6e6',
				'color_sidebar_widget_text'         => '#464637',
				'color_sidebar_widget_link'         => '#464637',
				'color_sidebar_widget_link_hover'   => '#ff794c',
				'color_sidebar_widget_list_border'  => '#d7d7d0',

				// Home Main Widgets.
				'color_home_main_widgets_title'           => '#6e6e6e',
				'color_home_main_widgets_title_underline' => '#e6e6e6',
				'color_home_main_widgets_text'            => '#6e6e6e',
				'color_home_main_widgets_link'            => '#ff794c',
				'color_home_main_widgets_link_hover'      => '#414042',

				// Home Left Widgets.
				'color_home_left_widgets_title'           => '#6e6e6e',
				'color_home_left_widgets_title_underline' => '#e6e6e6',
				'color_home_left_widgets_text'            => '#6e6e6e',
				'color_home_left_widgets_link'            => '#ff794c',
				'color_home_left_widgets_link_hover'      => '#414042',

				// Home Right Widgets.
				'color_home_right_widgets_title'           => '#6e6e6e',
				'color_home_right_widgets_title_underline' => '#e6e6e6',
				'color_home_right_widgets_text'            => '#6e6e6e',
				'color_home_right_widgets_link'            => '#ff794c',
				'color_home_right_widgets_link_hover'      => '#414042',

				// Home Bottom Widgets.
				'color_home_bottom_background'              => '#f9f9f9',
				'color_home_bottom_widgets_title'           => '#6e6e6e',
				'color_home_bottom_widgets_title_underline' => '#e6e6e6',
				'color_home_bottom_widgets_text'            => '#6e6e6e',
				'color_home_bottom_widgets_link'            => '#ff794c',
				'color_home_bottom_widgets_link_hover'      => '#414042',

				// Primary Menu.
				'color_primary_menu_main_background'    => '#888888',
				'color_primary_menu_main_link'          => '#ffffff',
				'color_primary_menu_main_link_hover'    => '#ffffff',
				'color_primary_menu_main_underline'     => '#242415',
				'color_primary_menu_submenu_background' => '#ffffff',
				'color_primary_menu_submenu_link'       => '#414042',
				'color_primary_menu_submenu_link_hover' => '#ff794c',

				// Slider.
				'color_slider_caption_background'        => '#000000',
				'color_slider_caption_border'            => '#ffffff',
				'color_slider_caption_title'             => '#ffffff',
				'color_slider_caption_title_hover'       => '#ffffff',
				'color_slider_caption_text'              => '#ffffff',
				'color_slider_next_prev_icon'            => '#ffffff',
				'color_slider_next_prev_icon_background' => '#ff794c',
				'color_slider_pager'                     => '#ffffff',
				'color_slider_pager_hover'               => '#ff794c',

				// Go To Top.
				'color_goto_top_icon'       => '#ff794c',
				'color_goto_top_icon_hover' => '#ff794c',

				// Pagination.
				'color_pagination_link'                  => '#ffffff',
				'color_pagination_link_hover'            => '#ffffff',
				'color_pagination_link_background'       => '#ff794c',
				'color_pagination_link_background_hover' => '#ff794c',

				// Footer Widgets.
				'color_footer_widgets_background'   => '#444444',
				'color_footer_widgets_title'        => '#ffffff',
				'color_footer_widgets_title_border' => '#e6e6e6',
				'color_footer_widgets_text'         => '#ffffff',
				'color_footer_widgets_link'         => '#ffffff',
				'color_footer_widgets_link_hover'   => '#ff794c',

				// Footer Copyright.
				'color_footer_copyright_background' => '#393939',
				'color_footer_copyright_text'       => '#f3f3f3',
				'color_footer_copyright_link'       => '#f3f3f3',
				'color_footer_copyright_link_hover' => '#ff794c',

				// Content Box.
				'color_content_box_background' => '#f9f9f9',
				);
			break;

		}
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_get_color_theme_settings_options' ) ) :

	/**
	 * Returns color theme settings options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_color_theme_settings_options() {

		$choices = array(

			// Basic.
			'color_basic_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_heading' => array(
				'label'   => __( 'Heading Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_button_text' => array(
				'label'   => __( 'Button Text Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_button_background' => array(
				'label'   => __( 'Button Background Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_button_text_hover' => array(
				'label'   => __( 'Button Text Hover Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),
			'color_basic_button_background_hover' => array(
				'label'   => __( 'Button Background Hover Color', 'wen-associate' ),
				'section' => 'color_section_basic',
				),

			// Header.
			'color_header_background' => array(
				'label'   => __( 'Header Background Color', 'wen-associate' ),
				'section' => 'color_section_header',
				),
			'color_header_title' => array(
				'label'   => __( 'Site Title Color', 'wen-associate' ),
				'section' => 'color_section_header',
				),
			'color_header_title_hover' => array(
				'label'   => __( 'Site Title Hover Color', 'wen-associate' ),
				'section' => 'color_section_header',
				),
			'color_header_tagline' => array(
				'label'   => __( 'Site Tagline Color', 'wen-associate' ),
				'section' => 'color_section_header',
				),

			// Header Top.
			'color_header_top_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_contact_icon' => array(
				'label'   => __( 'Contact Icon Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_contact_link' => array(
				'label'   => __( 'Contact Link Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_contact_link_hover' => array(
				'label'   => __( 'Contact Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_contact_separator' => array(
				'label'   => __( 'Contact Separator Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_quick_link' => array(
				'label'   => __( 'Quick Link Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_quick_link_hover' => array(
				'label'   => __( 'Quick Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_quick_link_hover_background' => array(
				'label'   => __( 'Quick Link Hover Background Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),
			'color_header_top_quick_link_separator' => array(
				'label'   => __( 'Quick Link Separator Color', 'wen-associate' ),
				'section' => 'color_section_header_top',
				),

			// Content.
			'color_content_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_title' => array(
				'label'   => __( 'Title Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_meta_text' => array(
				'label'   => __( 'Meta Text Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_meta_link' => array(
				'label'   => __( 'Meta Link Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_meta_link_hover' => array(
				'label'   => __( 'Meta Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),
			'color_content_meta_icon' => array(
				'label'   => __( 'Meta Icon Color', 'wen-associate' ),
				'section' => 'color_section_content',
				),

			// Sidebar.
			'color_sidebar_widget_background' => array(
				'label'   => __( 'Widget Background Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),
			'color_sidebar_widget_title' => array(
				'label'   => __( 'Widget Title Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),
			'color_sidebar_widget_title_border' => array(
				'label'   => __( 'Widget Title Border Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),
			'color_sidebar_widget_text' => array(
				'label'   => __( 'Widget Text Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),
			'color_sidebar_widget_link' => array(
				'label'   => __( 'Widget Link Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),
			'color_sidebar_widget_link_hover' => array(
				'label'   => __( 'Widget Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),
			'color_sidebar_widget_list_border' => array(
				'label'   => __( 'Widget List Border Color', 'wen-associate' ),
				'section' => 'color_section_sidebar',
				),


			// Home Main Widgets.
			'color_home_main_widgets_title' => array(
				'label'   => __( 'Title Color', 'wen-associate' ),
				'section' => 'color_section_home_main_widgets',
				),
			'color_home_main_widgets_title_underline' => array(
				'label'   => __( 'Title Underline Color', 'wen-associate' ),
				'section' => 'color_section_home_main_widgets',
				),
			'color_home_main_widgets_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_home_main_widgets',
				),
			'color_home_main_widgets_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_home_main_widgets',
				),
			'color_home_main_widgets_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_home_main_widgets',
				),

			// Home Left Widgets.
			'color_home_left_widgets_title' => array(
				'label'   => __( 'Title Color', 'wen-associate' ),
				'section' => 'color_section_home_left_widgets',
				),
			'color_home_left_widgets_title_underline' => array(
				'label'   => __( 'Title Underline Color', 'wen-associate' ),
				'section' => 'color_section_home_left_widgets',
				),
			'color_home_left_widgets_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_home_left_widgets',
				),
			'color_home_left_widgets_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_home_left_widgets',
				),
			'color_home_left_widgets_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_home_left_widgets',
				),

			// Home Right Widgets.
			'color_home_right_widgets_title' => array(
				'label'   => __( 'Title Color', 'wen-associate' ),
				'section' => 'color_section_home_right_widgets',
				),
			'color_home_right_widgets_title_underline' => array(
				'label'   => __( 'Title Underline Color', 'wen-associate' ),
				'section' => 'color_section_home_right_widgets',
				),
			'color_home_right_widgets_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_home_right_widgets',
				),
			'color_home_right_widgets_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_home_right_widgets',
				),
			'color_home_right_widgets_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_home_right_widgets',
				),

			// Home Bottom Widgets.
			'color_home_bottom_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_home_bottom_widgets',
				),
			'color_home_bottom_widgets_title' => array(
				'label'   => __( 'Title Color', 'wen-associate' ),
				'section' => 'color_section_home_bottom_widgets',
				),
			'color_home_bottom_widgets_title_underline' => array(
				'label'   => __( 'Title Underline Color', 'wen-associate' ),
				'section' => 'color_section_home_bottom_widgets',
				),
			'color_home_bottom_widgets_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_home_bottom_widgets',
				),
			'color_home_bottom_widgets_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_home_bottom_widgets',
				),
			'color_home_bottom_widgets_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_home_bottom_widgets',
				),

			// Primary Menu.
			'color_primary_menu_main_background' => array(
				'label'   => __( 'Main Background Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			'color_primary_menu_main_link' => array(
				'label'   => __( 'Main Link Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			'color_primary_menu_main_link_hover' => array(
				'label'   => __( 'Main Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			'color_primary_menu_main_underline' => array(
				'label'   => __( 'Main Underline Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			'color_primary_menu_submenu_background' => array(
				'label'   => __( 'Sub Menu Background Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			'color_primary_menu_submenu_link' => array(
				'label'   => __( 'Sub Menu Link Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			'color_primary_menu_submenu_link_hover' => array(
				'label'   => __( 'Sub Menu Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_primary_menu',
				),
			// Go To Top.
			'color_goto_top_icon' => array(
				'label'   => __( 'Icon Color', 'wen-associate' ),
				'section' => 'color_section_goto_top',
				),
			'color_goto_top_icon_hover' => array(
				'label'   => __( 'Icon Hover Color', 'wen-associate' ),
				'section' => 'color_section_goto_top',
				),

			// Pagination.
			'color_pagination_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_pagination',
				),
			'color_pagination_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_pagination',
				),
			'color_pagination_link_background' => array(
				'label'   => __( 'Link Background Color', 'wen-associate' ),
				'section' => 'color_section_pagination',
				),
			'color_pagination_link_background_hover' => array(
				'label'   => __( 'Link Background Hover Color', 'wen-associate' ),
				'section' => 'color_section_pagination',
				),

			// Slider.
			'color_slider_caption_background' => array(
				'label'   => __( 'Caption Background Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_caption_border' => array(
				'label'   => __( 'Caption Border Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_caption_title' => array(
				'label'   => __( 'Caption Title Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_caption_title_hover' => array(
				'label'   => __( 'Caption Title Hover Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_caption_text' => array(
				'label'   => __( 'Caption Text Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_next_prev_icon' => array(
				'label'   => __( 'Next Previous Icon Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_next_prev_icon_background' => array(
				'label'   => __( 'Next Previous Icon Background Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_pager' => array(
				'label'   => __( 'Pager Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),
			'color_slider_pager_hover' => array(
				'label'   => __( 'Pager Hover Color', 'wen-associate' ),
				'section' => 'color_section_slider',
				),

			// Footer Widgets.
			'color_footer_widgets_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_footer_widgets',
				),
			'color_footer_widgets_title' => array(
				'label'   => __( 'Title Color', 'wen-associate' ),
				'section' => 'color_section_footer_widgets',
				),
			'color_footer_widgets_title_border' => array(
				'label'   => __( 'Title Border Color', 'wen-associate' ),
				'section' => 'color_section_footer_widgets',
				),
			'color_footer_widgets_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_footer_widgets',
				),
			'color_footer_widgets_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_footer_widgets',
				),
			'color_footer_widgets_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_footer_widgets',
				),

			// Footer Copyright.
			'color_footer_copyright_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_footer_copyright',
				),
			'color_footer_copyright_text' => array(
				'label'   => __( 'Text Color', 'wen-associate' ),
				'section' => 'color_section_footer_copyright',
				),
			'color_footer_copyright_link' => array(
				'label'   => __( 'Link Color', 'wen-associate' ),
				'section' => 'color_section_footer_copyright',
				),
			'color_footer_copyright_link_hover' => array(
				'label'   => __( 'Link Hover Color', 'wen-associate' ),
				'section' => 'color_section_footer_copyright',
				),

			// Content Box.
			'color_content_box_background' => array(
				'label'   => __( 'Background Color', 'wen-associate' ),
				'section' => 'color_section_content_box',
				),

		);
		return $choices;

	}

endif;

if ( ! function_exists( 'wen_associate_get_color_sections_options' ) ) :

	/**
	 * Returns color sections options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_color_sections_options() {

		$choices = array(
			'color_section_basic' => array(
				'label' => __( 'Basic Color Options', 'wen-associate' ),
				),
			'color_section_header_top' => array(
				'label' => __( 'Top Header Color Options', 'wen-associate' ),
				),
			'color_section_header' => array(
				'label' => __( 'Header Color Options', 'wen-associate' ),
				),
			'color_section_primary_menu' => array(
				'label' => __( 'Primary Menu Color Options', 'wen-associate' ),
				),
			'color_section_slider' => array(
				'label' => __( 'Slider Color Options', 'wen-associate' ),
				),
			'color_section_home_main_widgets' => array(
				'label' => __( 'Home Main Widgets Color Options', 'wen-associate' ),
				),
			'color_section_home_left_widgets' => array(
				'label' => __( 'Home Left Widgets Color Options', 'wen-associate' ),
				),
			'color_section_home_right_widgets' => array(
				'label' => __( 'Home Right Widgets Color Options', 'wen-associate' ),
				),
			'color_section_home_bottom_widgets' => array(
				'label' => __( 'Home Bottom Widgets Color Options', 'wen-associate' ),
				),
			'color_section_content_box' => array(
				'label' => __( 'Content Box Color Options', 'wen-associate' ),
				),
			'color_section_content' => array(
				'label' => __( 'Content Color Options', 'wen-associate' ),
				),
			'color_section_sidebar' => array(
				'label' => __( 'Sidebar Color Options', 'wen-associate' ),
				),
			'color_section_goto_top' => array(
				'label' => __( 'Go To Top Color Options', 'wen-associate' ),
				),
			'color_section_pagination' => array(
				'label' => __( 'Pagination Color Options', 'wen-associate' ),
				),
			'color_section_footer_widgets' => array(
				'label' => __( 'Footer Widgets Color Options', 'wen-associate' ),
				),
			'color_section_footer_copyright' => array(
				'label' => __( 'Footer Copyright Color Options', 'wen-associate' ),
				),
			);
		return $choices;

	}

endif;
