<?php
/**
 * Hooks related to custom CSS.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_trigger_custom_css_action' ) ) :

	/**
	 * Do action theme custom CSS.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_trigger_custom_css_action() {

		do_action( 'wen_associate_action_theme_custom_css' );

	}

endif;

add_action( 'wp_head', 'wen_associate_trigger_custom_css_action', 99 );


if ( ! function_exists( 'wen_associate_add_custom_theme_option_css' ) ) :

	/**
	 * Add custom CSS.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_add_custom_theme_option_css() {

		$custom_css = wen_associate_get_option( 'custom_css' );
		$output = '';
		if ( ! empty( $custom_css ) ) {
			$output = "\n" . '<style type="text/css">' . "\n";
			$output .= $custom_css;
			$output .= "\n" . '</style>' . "\n";
		}
		echo $output;

	}

endif;

add_action( 'wen_associate_action_theme_custom_css', 'wen_associate_add_custom_theme_option_css', 99 );

if ( ! function_exists( 'wen_associate_add_theme_custom_font_css' ) ) :

	/**
	 * Inject theme custom font CSS.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_add_theme_custom_font_css() {

		$custom_css = '';

		$font_settings = wen_associate_get_font_family_theme_settings_options();

		$required_fonts = array();

		if ( ! empty( $font_settings ) ) {
			foreach ( $font_settings as $key => $val ) {
				$option_value = wen_associate_get_option( $key );
				if ( ! empty( $option_value ) && $val['default'] != $option_value ) {
					$required_fonts[ $key ] = $option_value;
				}
			}
		}
		if ( empty( $required_fonts ) ) {
			// We do not need extra CSS.
			return;
		}

		foreach ( $required_fonts as $key => $font ) {

			$family = wen_associate_get_font_family_from_key( $font );

			if ( ! empty( $family ) ) {

				switch ( $key ) {
					case 'font_site_default':
						$custom_css .= 'body{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_title':
						$custom_css .= '.site-title a{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_tagline':
						$custom_css .= '.site-description{font-family:' . $family . '}' . "\n";
					break;

					case 'font_heading_tags':
						$custom_css .= 'h1,h2,h3,h4,h5,h6{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_title':
						$custom_css .= '.entry-header .entry-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_body':
						$custom_css .= '#content,#content p{font-family:' . $family . '}' . "\n";
					break;

					case 'font_navigation':
						$custom_css .= '#site-navigation ul li a,#secondary-navigation ul li a{font-family:' . $family . '}' . "\n";
					break;

					case 'font_widget_title':
						$custom_css .= '.widget-title{font-family:' . $family . '}' . "\n";
					break;

					default:
					break;
				}
			}
		}

		// Render style.
		if ( ! empty( $custom_css ) ) {
			echo '<style type="text/css">';
			echo $custom_css;
			echo '</style>';
		}
		return ;

	}

endif;

add_action( 'wen_associate_action_theme_custom_css', 'wen_associate_add_theme_custom_font_css', 20 );


if( ! function_exists( 'wen_associate_add_theme_custom_color_css' ) ) :

  /**
   * Inject theme custom color CSS
   *
   * @since  1.0.0
   */
  function wen_associate_add_theme_custom_color_css(){

    $custom_css = '';

    $color_settings = wen_associate_get_color_theme_settings_options();
    // nspre($color_settings,'s');

    $default = wen_associate_get_default_colors();
    // nspre($default,'default');

    $required_colors = array();

    if ( ! empty( $color_settings ) ) {
      foreach ($color_settings as $key => $val ) {
        $option_value = wen_associate_get_option( $key );
        if ( ! empty( $option_value ) && $default[$key] != $option_value ) {
          $required_colors[ $key ] =  $option_value;
        }
      }
    }
    if ( empty( $required_colors ) ) {
      // We do not need extra CSS
      return;
    }

    foreach ( $required_colors as $key => $color ) {

      switch ( $key ) {

        // Basic
        case 'color_basic_background':
          $custom_css .= 'body.custom-background #page,body #page{background-color:' . $color . '}' . "\n";
          break;
        case 'color_basic_text':
          $custom_css .= 'body,p{color:' . $color . '}' . "\n";
          break;
        case 'color_basic_link':
          $custom_css .= 'a,.entry-title > a,.widget h3 > a,.widget h3.testimonial-title > a{color:' . $color . '}' . "\n";
          break;
        case 'color_basic_link_hover':
          $custom_css .= '.widget h3.testimonial-title > a:hover,a:hover,.service-block-item .fa:hover,.widget h3 > a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_basic_heading':
          $custom_css .= 'h1,h2,h3,h4,h5,h6,.entry-title > a,.widget h3 > a{color:' . $color . '}' . "\n";
          break;
        case 'color_basic_button_text':
          $custom_css .= '#btn-search-icon,button,.comment-reply-link, input[type="button"], input[type="reset"], input[type="submit"]{color:' . $color . '}' . "\n";
          if ( class_exists( 'WooCommerce' ) ) {
            $custom_css .= '.woocommerce #respond input#submit.alt,  .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt,.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button{color:' . $color . '}' . "\n";
            # code...
          }
          break;

        case 'color_basic_button_text_hover':
          $custom_css .= ',#btn-search-icon:hover.comment-reply-link:hover,button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover{color:' . $color . '}' . "\n";
          if ( class_exists( 'WooCommerce' ) ) {
            $custom_css .= '.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover.woocommerce #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt[disabled]:disabled, .woocommerce #respond input#submit.alt[disabled]:disabled:hover, .woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt[disabled]:disabled, .woocommerce a.button.alt[disabled]:disabled:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt[disabled]:disabled, .woocommerce button.button.alt[disabled]:disabled:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt[disabled]:disabled, .woocommerce input.button.alt[disabled]:disabled:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover{color:' . $color . '}' . "\n";
            # code...
          }
          break;
        case 'color_basic_button_background':
          $custom_css .= '#btn-search-icon,button.comment-reply-link, input[type="button"], input[type="reset"], input[type="submit"]{background-color:' . $color . '}' . "\n";
          if ( class_exists( 'WooCommerce' ) ) {
            $custom_css .= '.woocommerce #respond input#submit.alt,  .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt,.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button{background-color:' . $color . '}' . "\n";
          }
          break;
        case 'color_basic_button_background_hover':
          $custom_css .= '#btn-search-icon:hover,.comment-reply-link:hover,button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover{background-color:' . $color . '}' . "\n";
          if ( class_exists( 'WooCommerce' ) ) {
            $custom_css .= '.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover,.woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover.woocommerce #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt[disabled]:disabled, .woocommerce #respond input#submit.alt[disabled]:disabled:hover, .woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt[disabled]:disabled, .woocommerce a.button.alt[disabled]:disabled:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt[disabled]:disabled, .woocommerce button.button.alt[disabled]:disabled:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt[disabled]:disabled, .woocommerce input.button.alt[disabled]:disabled:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover:hover{background-color:' . $color . '}' . "\n";
            # code...
          }
          break;

        // Header
        case 'color_header_background':
          $custom_css .= '.site-header{background-color:' . $color . '}' . "\n";
          break;
        case 'color_header_title':
          $custom_css .= '.site-title a{color:' . $color . '}' . "\n";
          break;
        case 'color_header_title_hover':
          $custom_css .= '.site-title a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_header_tagline':
          $custom_css .= 'h2.site-description{color:' . $color . '}' . "\n";
          break;

        // Header Top.
        case 'color_header_top_background':
          $custom_css .= '#tophead{background-color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_contact_icon':
          $custom_css .= '#tophead #quick-contact ul li::before{color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_contact_link':
          $custom_css .= '#tophead #quick-contact a{color:' . $color . '}' . "\n";
          $custom_css .= '#quick-contact li::before,#quick-contact li a:hover::after{background-color:' . $color . '}' . "\n";
          break;

        case 'color_header_top_contact_link_hover':
          $custom_css .= '#tophead #quick-contact a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_contact_separator':
          $custom_css .= '#tophead #quick-contact li{border-color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_quick_link':
          $custom_css .= '#tophead #quick-links a{color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_quick_link_hover':
          $custom_css .= '#tophead #quick-links a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_quick_link_hover_background':
          $custom_css .= '#quick-links li a:hover, #quick-links li.current-menu-item > a, #quick-links li.current_page_item > a{background-color:' . $color . '}' . "\n";
          break;
        case 'color_header_top_quick_link_separator':
          $custom_css .= '#tophead #quick-links a{border-color:' . $color . '}' . "\n";
          break;

        // Primary Navigation
        case 'color_primary_menu_main_background':
          $custom_css .= '#site-navigation{background-color:' . $color . '}' . "\n";
          break;
        case 'color_primary_menu_main_link':
          $custom_css .= '#site-navigation ul li a{color:' . $color . '}' . "\n";
          break;
        case 'color_primary_menu_main_link_hover':
          $custom_css .= '#site-navigation .current_page_item > a, #site-navigation .current-menu-item > a, #site-navigation ul li > a:hover{color:' . $color . '}' . "\n";
          $custom_css .= ' #site-navigation li a:hover, #site-navigation li:hover > a, #site-navigation li.current-menu-item > a, #site-navigation li.current_page_item > a{border-color:' . $color . '}' . "\n";
          break;

         
        case 'color_primary_menu_main_underline':
          $custom_css .= '#site-navigation::after{background-color:' . $color . '}' . "\n";
          break;
        case 'color_primary_menu_submenu_background':
          $custom_css .= '#site-navigation ul ul{background-color:' . $color . '}' . "\n";
          break;
        case 'color_primary_menu_submenu_link':
          $custom_css .= '#site-navigation ul ul li a{color:' . $color . '}' . "\n";
          break;
        case 'color_primary_menu_submenu_link_hover':
          $custom_css .= '#site-navigation ul ul li a:hover, #site-navigation ul ul li.current_page_item a, #site-navigation ul ul li.current-menu-item a, #site-navigation ul ul li:hover > a,#site-navigation ul li li.menu-item-has-children:hover > a:before,#site-navigation ul li li.page_item_has_children:hover > a:before{color:' . $color . '}' . "\n";
          break;

        // Slider.
        case 'color_slider_caption_background':
          $custom_css .= '#main-slider .cycle-caption{background-color:' . $color . '}' . "\n";
          break;
        case 'color_slider_caption_border':
          $custom_css .= '#main-slider .cycle-caption{border-color:' . $color . '}' . "\n";
          break;
        case 'color_slider_caption_title':
          $custom_css .= '#main-slider .cycle-caption h3 a{color:' . $color . '}' . "\n";
          break;
        case 'color_slider_caption_title_hover':
          $custom_css .= '#main-slider .cycle-caption h3 a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_slider_caption_text':
          $custom_css .= '#main-slider .cycle-caption p{color:' . $color . '}' . "\n";
          break;
        case 'color_slider_next_prev_icon':
          $custom_css .= '#main-slider .cycle-prev:after, #main-slider .cycle-next:after{color:' . $color . '}' . "\n";
          break;
        case 'color_slider_next_prev_icon_background':
          $custom_css .= '#featured-slider .cycle-prev, #featured-slider .cycle-next{background-color:' . $color . '}' . "\n";
          break;
        case 'color_slider_pager':
          $custom_css .= '#main-slider .pager-box{background-color:' . $color . ';border:1px ' . $color . ' solid}' . "\n";
          break;
        case 'color_slider_pager_hover':
          $custom_css .= '#main-slider .pager-box:hover, #main-slider .pager-box.cycle-pager-active{background-color:' . $color . ';border:1px ' . $color . ' solid}' . "\n";
          break;

        // Home Main Widgets.
        case 'color_home_main_widgets_title':
          $custom_css .= '#sidebar-front-page-main .widget-title{color:' . $color . '}' . "\n";
          break;
        case 'color_home_main_widgets_title_underline':
          $custom_css .= '#sidebar-front-page-main .widget .widget-title::after{border-color:' . $color . '}' . "\n";
          break;
        case 'color_home_main_widgets_text':
          $custom_css .= '#sidebar-front-page-main{color:' . $color . '}' . "\n";
          break;
        case 'color_home_main_widgets_link':
          $custom_css .= '#sidebar-front-page-main a{color:' . $color . '}' . "\n";
          break;
        case 'color_home_main_widgets_link_hover':
          $custom_css .= '#sidebar-front-page-main a:hover{color:' . $color . '}' . "\n";
          break;

        // Home Left Widgets.
        case 'color_home_left_widgets_title':
          $custom_css .= '#sidebar-front-page-lower-left .widget-title{color:' . $color . '}' . "\n";
          break;
        case 'color_home_left_widgets_title_underline':
          $custom_css .= '#sidebar-front-page-lower-left .widget .widget-title::after{border-color:' . $color . '}' . "\n";
          break;
        case 'color_home_left_widgets_text':
          $custom_css .= '#sidebar-front-page-lower-left{color:' . $color . '}' . "\n";
          break;
        case 'color_home_left_widgets_link':
          $custom_css .= '#sidebar-front-page-lower-left a{color:' . $color . '}' . "\n";
          break;
        case 'color_home_left_widgets_link_hover':
          $custom_css .= '#sidebar-front-page-lower-left a:hover{color:' . $color . '}' . "\n";
          break;

        // Home Right Widgets.
        case 'color_home_right_widgets_title':
          $custom_css .= '#sidebar-front-page-lower-right .widget-title{color:' . $color . '}' . "\n";
          break;
        case 'color_home_right_widgets_title_underline':
          $custom_css .= '#sidebar-front-page-lower-right .widget .widget-title::after{border-color:' . $color . '}' . "\n";
          break;
        case 'color_home_right_widgets_text':
          $custom_css .= '#sidebar-front-page-lower-right{color:' . $color . '}' . "\n";
          break;
        case 'color_home_right_widgets_link':
          $custom_css .= '#sidebar-front-page-lower-right a{color:' . $color . '}' . "\n";
          break;
        case 'color_home_right_widgets_link_hover':
          $custom_css .= '#sidebar-front-page-lower-right a:hover{color:' . $color . '}' . "\n";
          break;

        // Home Bottom Widgets.
        case 'color_home_bottom_background':
          $custom_css .= '#sidebar-front-page-bottom {background-color:' . $color . '}' . "\n";
          break;
        case 'color_home_bottom_widgets_title':
          $custom_css .= '#sidebar-front-page-bottom .widget-title{color:' . $color . '}' . "\n";
          break;
        case 'color_home_bottom_widgets_title_underline':
          $custom_css .= '#sidebar-front-page-bottom .widget .widget-title::after{border-color:' . $color . '}' . "\n";
          break;
        case 'color_home_bottom_widgets_text':
          $custom_css .= '#sidebar-front-page-bottom{color:' . $color . '}' . "\n";
          break;
        case 'color_home_bottom_widgets_link':
          $custom_css .= '#sidebar-front-page-bottom a{color:' . $color . '}' . "\n";
          break;
        case 'color_home_bottom_widgets_link_hover':
          $custom_css .= '#sidebar-front-page-bottom a:hover{color:' . $color . '}' . "\n";
          break;

        // Content Box
        case 'color_content_box_background':
          $custom_css .= '#content{background-color:' . $color . '}' . "\n";
          break;

        // Content
        case 'color_content_background':
          $custom_css .= '#primary{background-color:' . $color . '}' . "\n";
          break;
        case 'color_content_title':
          $custom_css .= '.entry-header .entry-title, .entry-header .entry-title a{color:' . $color . '}' . "\n";
          break;
        case 'color_content_text':
          $custom_css .= '#primary p{color:' . $color . '}' . "\n";
          break;
        case 'color_content_link':
          $custom_css .= '#primary a{color:' . $color . '}' . "\n";
          break;
        case 'color_content_link_hover':
          $custom_css .= '#primary a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_content_meta_text':
          $custom_css .= '.posted-on > a, .byline a{color:' . $color . '}' . "\n";
          break;
        case 'color_content_meta_link':
          $custom_css .= '.posted-on > a, .byline a{color:' . $color . '}' . "\n";
          break;
        case 'color_content_meta_link_hover':
          $custom_css .= '.posted-on > a:hover, .byline a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_content_meta_icon':
          $custom_css .= '.posted-on:after, .byline:after, .comment:after{color:' . $color . '}' . "\n";
          break;

        // Sidebar.
        case 'color_sidebar_widget_background':
          $custom_css .= '.sidebar .widget{background-color:' . $color . '}' . "\n";
          break;
        case 'color_sidebar_widget_title':
          $custom_css .= '.sidebar .widget-title{color:' . $color . '}' . "\n";
          break;
        case 'color_sidebar_widget_title_border':
          $custom_css .= '.sidebar .widget .widget-title::after{border-color:' . $color . '}' . "\n";
          break;
        case 'color_sidebar_widget_text':
          $custom_css .= '.sidebar{color:' . $color . '}' . "\n";
          break;
        case 'color_sidebar_widget_link':
          $custom_css .= '.sidebar a{color:' . $color . '}' . "\n";
          break;
        case 'color_sidebar_widget_link_hover':
          $custom_css .= '.sidebar a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_sidebar_widget_list_border':
          $custom_css .= '.sidebar ul li{border-color:' . $color . '}' . "\n";
          break;

        // Footer Widgets
        case 'color_footer_widgets_background':
          $custom_css .= '#footer-widgets{background-color:' . $color . '}' . "\n";
          break;
        case 'color_footer_widgets_title':
          $custom_css .= '#footer-widgets .widget-title{color:' . $color . '}' . "\n";
          break;
        case 'color_footer_widgets_title_border':
          $custom_css .= '#footer-widgets h3.widget-title{border-color:' . $color . '}' . "\n";
          break;
        case 'color_footer_widgets_text':
          $custom_css .= '#footer-widgets,.footer-widget-area ul li::after{color:' . $color . '}' . "\n";
          break;
        case 'color_footer_widgets_link':
          $custom_css .= '#footer-widgets a{color:' . $color . '}' . "\n";
          break;
        case 'color_footer_widgets_link_hover':
          $custom_css .= '#footer-widgets a:hover{color:' . $color . '}' . "\n";
          break;

        // Footer Copyright
        case 'color_footer_copyright_background':
          $custom_css .= '#colophon{background-color:' . $color . '}' . "\n";
          break;
        case 'color_footer_copyright_text':
          $custom_css .= '#colophon{color:' . $color . '}' . "\n";
          break;
        case 'color_footer_copyright_link':
          $custom_css .= '#colophon a{color:' . $color . '}' . "\n";
          break;
        case 'color_footer_copyright_link_hover':
          $custom_css .= '#colophon a:hover{color:' . $color . '}' . "\n";
          break;

        // Go To Top
        case 'color_goto_top_icon':
          $custom_css .= '.scrollup i:before{color:' . $color . '}' . "\n";
          break;
        case 'color_goto_top_icon_hover':
          $custom_css .= '.scrollup i:hover::before{color:' . $color . '}' . "\n";
          break;

        // Pagination
        case 'color_pagination_link':
          $custom_css .= '.pagination .nav-links > a, .pagination .nav-links > span, .wp-pagenavi a, .wp-pagenavi span,.navigation .nav-links a{color:' . $color . '}' . "\n";
          break;
        case 'color_pagination_link_hover':
          $custom_css .= '.pagination .nav-links > span.current, .pagination .nav-links > a:hover, .wp-pagenavi span.current, .wp-pagenavi a:hover,.navigation .nav-links a:hover{color:' . $color . '}' . "\n";
          break;
        case 'color_pagination_link_background':
          $custom_css .= '.pagination .nav-links > a, .pagination .nav-links > span, .wp-pagenavi a, .wp-pagenavi span,.navigation .nav-links a{background-color:' . $color . '}' . "\n";
          break;
        case 'color_pagination_link_background_hover':
          $custom_css .= '.pagination .nav-links > span.current, .pagination .nav-links > a:hover, .wp-pagenavi span.current, .wp-pagenavi a:hover,.navigation .nav-links a:hover{background-color:' . $color . '}' . "\n";
          break;

        default:
          break;

      } // end switch

    } //end if


    // Render style
    if ( ! empty( $custom_css ) ) {
      echo '<style type="text/css">';
      echo $custom_css;
      echo '</style>';
    }

    return ;

  }

endif;

add_action( 'wen_associate_action_theme_custom_css', 'wen_associate_add_theme_custom_color_css', 30 );
